<p align="center">
    <img src="https://d1nheu3uhuz51e.cloudfront.net/nun/nun-logo-light.png" width="425" alt="nun Logo">
</p>

<div align="center">
<a href="https://pypi.org/project/nun"><img 
    alt="Supported Python Versions"
    src="https://img.shields.io/pypi/pyversions/nun?logo=data%3Aimage%2Fsvg%2Bxml%3Bbase64%2CPHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxLjAxZW0iIGhlaWdodD0iMWVtIiB2aWV3Qm94PSIwIDAgMjU2IDI1NSI%2BPGRlZnM%2BPGxpbmVhckdyYWRpZW50IGlkPSJsb2dvc1B5dGhvbjAiIHgxPSIxMi45NTklIiB4Mj0iNzkuNjM5JSIgeTE9IjEyLjAzOSUiIHkyPSI3OC4yMDElIj48c3RvcCBvZmZzZXQ9IjAlIiBzdG9wLWNvbG9yPSIjMzg3ZWI4Ii8%2BPHN0b3Agb2Zmc2V0PSIxMDAlIiBzdG9wLWNvbG9yPSIjMzY2OTk0Ii8% % %2BPC9zdmc%2B&labelColor=blue&color=yellow"></a>
<a href="https://pypi.org/project/nun/"><img 
    alt="PyPI - Version"
    src="https://img.shields.io/pypi/v/nun?logo=pypi&label=PyPi&labelColor=white&color=blue"></a>
<a href="https://pypi.org/project/nun/"><img 
    alt="PyPI - License"
    src="https://img.shields.io/pypi/l/nun?logo=data%3Aimage%2Fsvg%2Bxml%3Bbase64%2CPHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxZW0iIGhlaWdodD0iMWVtIiB2aWV3Qm94PSIwIDAgMTYgMTYiPjxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzk3OTc5NyIgc3Ryb2tlLWxpbmVjYXA9InJvdW5kIiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBkPSJNNC41IDEzLjVoN004LjAxIDF2MTIuMDZNMS41IDMuNWgzbDEuNS0xaDRsMS41IDFoM00uNSAxMEwzIDQuNDhMNS41IDEwQzQgMTEgMiAxMSAuNSAxMG0xMCAwTDEzIDQuNDhMMTUuNSAxMGMtMS41IDEtMy41IDEtNSAwIi8%2BPC9zdmc%2B&labelColor=darkred&color=lightgrey"></a>
<br>
<a href="https://nun.readthedocs.io/en/latest/api_reference"><img
    alt="Read the Docs"
    src="https://img.shields.io/readthedocs/nun?logo=data%3Aimage%2Fsvg%2Bxml%3Bbase64%2CPHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIyNTYiIGhlaWdodD0iMjU2IiB2aWV3Qm94PSIwIDAgNDggNDgiPjxwYXRoIGZpbGw9IiM5MGNhZjkiIGQ9Ik00MCA0NUg4VjNoMjJsMTAgMTB6Ii8%2BPHBhdGggZmlsbD0iI2UxZjVmZSIgZD0iTTM4LjUgMTRIMjlWNC41eiIvPjxwYXRoIGZpbGw9IiMxOTc2ZDIiIGQ9Ik0xNiAyMWgxN3YySDE2em0wIDRoMTN2MkgxNnptMCA0aDE3djJIMTZ6bTAgNGgxM3YySDE2eiIvPjwvc3ZnPg%3D%3D&labelColor=white"></a>
<a href="https://github.com/MitchMedeiros/nun/actions/workflows/lint.yml"><img
    alt="GitHub Actions Workflow Status"
    src="https://img.shields.io/github/actions/workflow/status/MitchMedeiros/nun/lint.yml?logo=data%3Aimage%2Fsvg%2Bxml%3Bbase64% %2BPC9zdmc%2B&label=Lint&labelColor=lightgreen"></a>
<a href="https://github.com/MitchMedeiros/nun/actions/workflows/unit-tests.yml"><img
    alt="GitHub Actions status (MacOS Unit Tests)"
    src="https://img.shields.io/github/actions/workflow/status/MitchMedeiros/nun/unit-tests.yml?logo=data%3Aimage%2Fsvg%2Bxml%3Bbase64%2CPHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxZW0iIGhlaWdodD0iMWVtIiB2aWV3Qm94PSIwIDAgMTI4IDEyOCI%2BPHBhdGggZmlsbD0iIzY5Njk2OSIgZD0iTTMxLjUxMiAzMC4zOThoNjEuMzA0YTMuMDA2IDMuMDA2IDAgMCAxIDAgNi4wMTJIMzEuNTEyYTMuMDA3IDMuMDA3IDAgMCAxLTMuMDA0LTMuMDA0YTMuMDEgMy4wMSAwIDAgMSAzLjAwNC0zLjAwOG0wIDAiLz48cGF0aCBmaWxsPSIjMDA5ZmUzIiBkPSJNMzIuMDQ3IDI0LjMySDQ0LjM3djIuODQ0SDMyLjA0N3ptMCAwIi8% %3D%3D&label=Unit%20Tests&labelColor=darkgreen"></a>
<a href="https://app.codecov.io/gh/MitchMedeiros/nun"><img
    alt="Code Coverage"
    src="https://img.shields.io/codecov/c/github/MitchMedeiros/nun?logo=codecov&labelColor=black"></a>
</div>

<br>

A Python package still in early development :)

<h2>Installing</h2>

```console
pip install nun
```

<h2>A Simple Example</h2>

```python
import nun

nun.pray()
```
